*********
Front-end
*********

Front-end components are:

#. cross-browsers
#. supported different desktop and mobile OS 
#. minified
#. gziped
#. applied Content Security Policy

CSS, HTML
=========

CSS and HTML follow `Google HTML/CSS Style Guide <https://google.github.io/styleguide/htmlcssguide.xml>`_.

JScript
=======

JScript follows as much as possible `The JavaScript Manifesto <http://www.webstandards.org/action/dstf/manifesto/>`_.
